
# Retell Ai MCP Server

An MCP Server for the Retell Ai API.

## Supported Integrations

- AgentR
- API Key (Coming Soon)
- OAuth (Coming Soon)

## Tools

This is automatically generated from OpenAPI schema for the Retell Ai API.

## Supported Integrations

This tool can be integrated with any service that supports HTTP requests.

## Tool List

| Tool | Description |
|------|-------------|
| get_v2_get_call_by_call_id | Retrieve detailed information about a specific call using its call ID. |
| post_v2_create_phone_call | Initiates a phone call using a JSON payload with specified parameters. |
| post_v2_create_web_call | Creates a web call via a POST request to the v2 endpoint with specified agent ID and optional metadata or dynamic variables. |
| get_get_voice_by_voice_id | Fetches voice details based on the provided voice ID. |
| post_v2_list_calls | Sends a POST request to list call records with optional filtering, sorting, pagination, and limits. |
| post_create_phone_number | Creates a phone number with the specified area code and optional parameters. |
| get_get_phone_number_by_phone_number | Retrieves phone number details by making a GET request to the API endpoint using the provided phone number. |
| get_list_phone_numbers | Retrieves a list of phone numbers from the remote API. |
| patch_update_phone_number_by_phone_number | Updates the information of a phone number by its number, allowing optional modification of inbound and outbound agent IDs and nickname. |
| delete_delete_phone_number_by_phone_number | Deletes a phone number resource by its phone number identifier via an HTTP DELETE request. |



## Usage

- Login to AgentR
- Follow the quickstart guide to setup MCP Server for your client
- Visit Apps Store and enable the Retell Ai app
- Restart the MCP Server

### Local Development

- Follow the README to test with the local MCP Server
